//
//  ViewController.m
//  enhancedemo
//
//  Enhance, Inc.
//  www.enhance.co

#import "ViewController.h"
#import "Enhance.h"

@implementation ViewController

@synthesize isBannerAdShown;
@synthesize hasLocalNotificationPermission;

- (void)viewDidLoad {
    [super viewDidLoad];
    [self updateStatus];
    
    // Ask for permission to show local notifications
    // This can be done at any point in the application
    
    [Enhance requestLocalNotificationPermission:self];
    
    // Set currency delegate (offerwalls)
    
    [Enhance setCurrencyGrantedDelegate:self];
    
    [self updateIAPLabel];
}

-(void)updateStatus {
    dispatch_after(dispatch_time(DISPATCH_TIME_NOW, 1 * NSEC_PER_SEC), dispatch_get_main_queue(), ^{
        [self updateStatus];
    });
}

// Interstitial Ad

-(IBAction)onShowInterstitialAd:(id)sender {
    // Check whether an interstitial ad is available
    
    bool isInterstitialReady = [Enhance isInterstitialReady];

    if(!isInterstitialReady) {
        [self writeLog:@"Interstitial ad is not ready"];
        return;
    }
    
    // The ad is ready, show it
    
    [Enhance showInterstitialAd];
    [self writeLog:@"Showing interstitial ad"];
}

// Rewarded Ad

-(IBAction)onShowRewardedAd:(id)sender {
    // Check whether a rewarded ad is available
    
    bool isRewardedAdReady = [Enhance isRewardedAdReady];
    
    if(!isRewardedAdReady) {
        [self writeLog:@"Rewarded ad is not ready"];
        return;
    }
    
    // The ad is ready, show it
    
    [Enhance showRewardedAd:self];
    [self writeLog:@"Showing rewarded ad"];
}

// Banner Ad

-(IBAction)onToggleBannerAd:(id)sender {
    // If any banner ad is already visible, hide it
    
    if (isBannerAdShown) {
        isBannerAdShown = false;
        [Enhance hideBannerAd];
        [self writeLog:@"Hiding banner ad"];
        return;
    }
    
    // It's not shown, check if the ad is available
    
    bool isBannerAdReady = [Enhance isBannerAdReady];
    
    if(!isBannerAdReady) {
        [self writeLog:@"Banner ad is not ready"];
        return;
    }
    
    // It's ready, show it
    
    [Enhance showBannerAdWithPosition:POSITION_BOTTOM];
    [self writeLog:@"Showing banner ad"];
    isBannerAdShown = true;
    
    // This will display the ad at the bottom of your screen
    // You can also change the position to POSITITION_TOP
}

// Analytics

-(IBAction)onLogEvent:(id)sender {
    // Send a custom event to analytics network (e.g. Google Analytics)
    
    [Enhance logEvent:@"event_type"];
    [self writeLog:@"Sent analytics event"];
    
    // You can also add an additional parameter to your custom event, for example:
    [Enhance logEvent:@"event_type" withParameter:@"event_param_key" andValue:@"event_param_value"];
}

// Offerwall

-(IBAction)onShowOfferwall:(id)sender {
    // Check whether an offerwall is available
    
    bool isOfferwallReady = [Enhance isOfferwallReady];
    
    if(!isOfferwallReady) {
        [self writeLog:@"Offerwall is not ready"];
        return;
    }
    
    // The offerwall is ready, show it
    
    [Enhance showOfferwall];
    [self writeLog:@"Showing offerwall"];
}

// Special Offer

-(IBAction)onShowSpecialOffer:(id)sender {
    // Check whether a special offer is available
    
    bool isSpecialOfferReady = [Enhance isSpecialOfferReady];
    
    if(!isSpecialOfferReady) {
        [self writeLog:@"Special offer is not ready"];
        return;
    }
    
    // The special offer is available, show it
    
    [Enhance showSpecialOffer];
    [self writeLog:@"Showing special offer"];
}

// Local Notification

-(IBAction)onEnableLocalNotification:(id)sender {
    // Check whether the app received a permission to schedule local notifications
    
    if(!hasLocalNotificationPermission) {
        [self writeLog:@"Permission is not granted"];
        return;
    }
    
    // We have permission, enable a new local notification
    
    [Enhance enableLocalNotificationWithTitle:@"Enhance" message:@"Local Notification!" delay:5];
    [self writeLog:@"Enabled local notification"];
}

-(IBAction)onDisableLocalNotification:(id)sender {
    // Cancel previously scheduled local notification
    
    [Enhance disableLocalNotification];
    [self writeLog:@"Disabled local notification"];
}

// IAP

-(IBAction)onPurchaseIAP:(id)sender {
    [self writeLog:@"Attempting Purchase"];
    [[Enhance purchases] attemptPurchase:@"Enhance_SKU_One" delegate:self];
    
}

-(IBAction)onConsumeIAP:(id)sender {
    [self writeLog:@"Attempting Consume"];
    [[Enhance purchases] consume:@"Enhance_SKU_One" delegate:self];
    
}

// GDPR
-(IBAction)onShowDialogsForGDPR:(id)sender {
    // Check if any SDK included requires opt-in dialog
    [Enhance requiresDataConsentOptIn:self];
}

-(void)onServiceOptInRequirement:(BOOL)isUserOptInRequired {
    if(isUserOptInRequired) {
        // Show dialogs for all SDKs that provide them
        [Enhance showServiceOptInDialogs];
    }
}

-(void)onOptInDialogComplete {
    [self writeLog:@"Finished displaying opt-in dialogs"];
}

-(IBAction)onOptInGDPR:(id)sender {
    [self writeLog:@"Opted into GDPR"];
    [Enhance serviceTermsOptIn];
}

-(IBAction)onOptOutGDPR:(id)sender {
    [self writeLog:@"Opted out of GDPR"];
    [Enhance serviceTermsOptOut];
}

-(void)updateIAPLabel {
    _IAPLabel.text = [NSString stringWithFormat:@"%@ - %@ - Qty: %d", [[Enhance purchases] getDisplayTitle:@"Enhance_SKU_One" defaultTitle:@"Default Title"], [[Enhance purchases] getDisplayPrice:@"Enhance_SKU_One" defaultPrice:@"Default Price"], [[Enhance purchases] getOwnedItemCount:@"Enhance_SKU_One"] ];
}

// RewardedDelegate implementation

-(void)onRewardGranted:(int)rewardValue rewardType:(RewardType)rewardType {
    // Reward is granted to the user (watched video for example)
    // You can check reward type
    
    if(rewardType == REWARDTYPE_ITEM) {
        [self writeLog:@"Reward granted (item)"];
    }
    else if(rewardType == REWARDTYPE_COINS) {
        [self writeLog:@"Reward granted (coins)"];
        [self writeLog:[NSString stringWithFormat:@"Reward value: %d", rewardValue]];
    }
    else {
        [self writeLog:@"Unknown reward granted"];
    }
}

-(void)onRewardDeclined {
    // Reward is declined (user closed ad for example)
    
    [self writeLog:@"Reward declined"];
}

-(void)onRewardUnavailable {
    // Reward is unavailable (network error for example)
    
    [self writeLog:@"Reward unavailable"];
}

// PermissionDelegate implementation

-(void)onPermissionGranted {
    hasLocalNotificationPermission = YES;
}

-(void)onPermissionRefused {
    hasLocalNotificationPermission = NO;
}

// CurrencyDelegate implementation

-(void)onCurrencyGranted:(int)amount {
    // User received a reward from offerwall network
    [self writeLog:[NSString stringWithFormat:@"Currency granted: %d", amount]];
}

// PurchaseDelegate implementation

-(void)onPurchaseSuccess {
    // Purchase success
    [self updateIAPLabel];
    [self writeLog:@"Purchase Success"];
}

-(void)onPurchaseFailed {
    // Purchase Failed
    [self writeLog:@"Purchase Failed"];
}

// ConsumeDelegate implementation

-(void)onConsumeSuccess {
    // Consume success
    [self updateIAPLabel];
    [self writeLog:@"Consume Success"];
}

-(void)onConsumeFailed {
    // Consume Failed
    [self writeLog:@"Consume Failed"];
}

// Non-enhance logic
// Write logs to screen

-(void)writeLog:(NSString*) text {
    UITextField *logs = [self.view viewWithTag:1];
    
    NSDateFormatter *dateFormatter=[[NSDateFormatter alloc] init];
    [dateFormatter setDateFormat:@"hh:mm:ss: "];
    NSString *timeString = [dateFormatter stringFromDate:[NSDate date]];
    
    logs.text = [timeString stringByAppendingString:text];
}

@end
